#ifndef NT2_INCLUDE_CONSTANTS_PIX_4_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_PIX_4_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/pix_4.hpp>

#endif
